@@ -89,8 +89,8 @@ struct WeatherInfo MetarParser::processData(const QString &stationID, const QStr
 	bool found = false;
 	bool beforeRemark = true;
 
-	for (QStringList::ConstIterator it = dataList.begin();
-	     it != dataList.end(); ++it)
+	for (QStringList::ConstIterator it = dataList.constBegin();
+	     it != dataList.constEnd(); ++it)
 	{
 		// Don't try to parse the ICAO location code
 		if ((!found) && (*it == weatherInfo.reportLocation.toUpper().trimmed()))
